@@ -2,15 +2,11 @@ use strict;
 use warnings;
 package YAML::PP::Common;
 
-our $VERSION = 'v0.39.0'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 use base 'Exporter';
 
-my @p = qw/
-    PRESERVE_ALL PRESERVE_ORDER PRESERVE_SCALAR_STYLE PRESERVE_FLOW_STYLE
-    PRESERVE_ALIAS
-/;
-my @s = qw/
+our @EXPORT_OK = qw/
     YAML_ANY_SCALAR_STYLE YAML_PLAIN_SCALAR_STYLE
     YAML_SINGLE_QUOTED_SCALAR_STYLE YAML_DOUBLE_QUOTED_SCALAR_STYLE
     YAML_LITERAL_SCALAR_STYLE YAML_FOLDED_SCALAR_STYLE
@@ -22,36 +18,23 @@ my @s = qw/
     YAML_ANY_MAPPING_STYLE
     YAML_BLOCK_MAPPING_STYLE YAML_FLOW_MAPPING_STYLE
 /;
-our @EXPORT_OK = (@s, @p);
-
-our %EXPORT_TAGS = (
-    PRESERVE => [@p],
-    STYLES => [@s],
-);
 
 use constant {
-    YAML_ANY_SCALAR_STYLE           => 0,
-    YAML_PLAIN_SCALAR_STYLE         => 1,
-    YAML_SINGLE_QUOTED_SCALAR_STYLE => 2,
-    YAML_DOUBLE_QUOTED_SCALAR_STYLE => 3,
-    YAML_LITERAL_SCALAR_STYLE       => 4,
-    YAML_FOLDED_SCALAR_STYLE        => 5,
-    YAML_QUOTED_SCALAR_STYLE        => 'Q', # deprecated
+    YAML_ANY_SCALAR_STYLE           => 'A',
+    YAML_PLAIN_SCALAR_STYLE         => ':',
+    YAML_SINGLE_QUOTED_SCALAR_STYLE => "'",
+    YAML_DOUBLE_QUOTED_SCALAR_STYLE => '"',
+    YAML_LITERAL_SCALAR_STYLE       => '|',
+    YAML_FOLDED_SCALAR_STYLE        => '>',
+    YAML_QUOTED_SCALAR_STYLE        => 'Q',
 
-    YAML_ANY_SEQUENCE_STYLE   => 0,
-    YAML_BLOCK_SEQUENCE_STYLE => 1,
-    YAML_FLOW_SEQUENCE_STYLE  => 2,
+    YAML_ANY_SEQUENCE_STYLE   => 'any',
+    YAML_BLOCK_SEQUENCE_STYLE => 'block',
+    YAML_FLOW_SEQUENCE_STYLE  => 'flow',
 
-    YAML_ANY_MAPPING_STYLE   => 0,
-    YAML_BLOCK_MAPPING_STYLE => 1,
-    YAML_FLOW_MAPPING_STYLE  => 2,
-
-    PRESERVE_ORDER        => 2,
-    PRESERVE_SCALAR_STYLE => 4,
-    PRESERVE_FLOW_STYLE   => 8,
-    PRESERVE_ALIAS        => 16,
-
-    PRESERVE_ALL          => 31,
+    YAML_ANY_MAPPING_STYLE   => 'any',
+    YAML_BLOCK_MAPPING_STYLE => 'block',
+    YAML_FLOW_MAPPING_STYLE  => 'flow',
 };
 
 my %scalar_style_to_string = (
@@ -64,7 +47,7 @@ my %scalar_style_to_string = (
 
 
 sub event_to_test_suite {
-    my ($event, $args) = @_;
+    my ($event) = @_;
     my $ev = $event->{name};
         my $string;
         my $content = $event->{value};
@@ -89,22 +72,22 @@ sub event_to_test_suite {
         }
         elsif ($ev eq 'mapping_start_event') {
             $string = "+MAP";
-            if ($event->{style} and $event->{style} eq YAML_FLOW_MAPPING_STYLE) {
-                $string .= ' {}' if $args->{flow};
-            }
             $string .= $properties;
             if (0) {
                 # doesn't match yaml-test-suite format
+                if ($event->{style} and $event->{style} eq YAML_FLOW_MAPPING_STYLE) {
+                    $string .= " {}";
+                }
             }
         }
         elsif ($ev eq 'sequence_start_event') {
             $string = "+SEQ";
-            if ($event->{style} and $event->{style} eq YAML_FLOW_SEQUENCE_STYLE) {
-                $string .= ' []' if $args->{flow};
-            }
             $string .= $properties;
             if (0) {
                 # doesn't match yaml-test-suite format
+                if ($event->{style} and $event->{style} eq YAML_FLOW_SEQUENCE_STYLE) {
+                    $string .= " []";
+                }
             }
         }
         elsif ($ev eq 'mapping_end_event') {
@@ -116,13 +99,16 @@ sub event_to_test_suite {
         elsif ($ev eq 'scalar_event') {
             $string = '=VAL';
             $string .= $properties;
-
-            $content =~ s/\\/\\\\/g;
-            $content =~ s/\t/\\t/g;
-            $content =~ s/\r/\\r/g;
-            $content =~ s/\n/\\n/g;
-            $content =~ s/[\b]/\\b/g;
-
+            if (defined $content) {
+                $content =~ s/\\/\\\\/g;
+                $content =~ s/\t/\\t/g;
+                $content =~ s/\r/\\r/g;
+                $content =~ s/\n/\\n/g;
+                $content =~ s/[\b]/\\b/g;
+            }
+            else {
+                $content = '';
+            }
             $string .= ' '
                 . $scalar_style_to_string{ $event->{style} }
                 . $content;
@@ -223,34 +209,16 @@ YAML::PP::Common - Constants and common functions
 
 =head1 SYNOPSIS
 
-    use YAML::PP::Common ':STYLES';
-    # or
     use YAML::PP::Common qw/
         YAML_ANY_SCALAR_STYLE YAML_PLAIN_SCALAR_STYLE
         YAML_SINGLE_QUOTED_SCALAR_STYLE YAML_DOUBLE_QUOTED_SCALAR_STYLE
         YAML_LITERAL_SCALAR_STYLE YAML_FOLDED_SCALAR_STYLE
         YAML_QUOTED_SCALAR_STYLE
-
-        YAML_ANY_SEQUENCE_STYLE
-        YAML_BLOCK_SEQUENCE_STYLE YAML_FLOW_SEQUENCE_STYLE
-
-        YAML_ANY_MAPPING_STYLE
-        YAML_BLOCK_MAPPING_STYLE YAML_FLOW_MAPPING_STYLE
     /;
 
-    use YAML::PP::Common ':PRESERVE';
-    # or
-    use YAML::PP::Common qw/
-        PRESERVE_ALL PRESERVE_ORDER PRESERVE_SCALAR_STYLE PRESERVE_FLOW_STYLE
-        PRESERVE_ALIAS
-    /:
-
 =head1 DESCRIPTION
 
-This module provides common constants and functions for modules working with
-YAML::PP events.
-
-=head1 FUNCTIONS
+=head1 FUNCTONS
 
 =over
 
@@ -262,12 +230,5 @@ For examples of the returned format look into this distributions's directory
 C<yaml-test-suite> which is a copy of
 L<https://github.com/yaml/yaml-test-suite>.
 
-=item test_suite_to_event
-
-    my $event = YAML::PP::Common::test_suite_to_event($str);
-
-Turns an event string in test suite format into an event hashref. Not complete
-yet.
-
 =back
 
