@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package YAML::PP::Schema::Tie::IxHash;
 
-our $VERSION = 'v0.38.1'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 use base 'YAML::PP::Schema';
 
@@ -37,13 +37,14 @@ __END__
 
 =head1 NAME
 
-YAML::PP::Schema::Tie::IxHash - (Deprecated) Schema for serializing ordered hashes
+YAML::PP::Schema::Tie::IxHash - Schema for serializing ordered hashes
 
 =head1 SYNOPSIS
 
     use YAML::PP;
     use Tie::IxHash;
-    my $yp = YAML::PP->new( schema => [qw/ + Tie::IxHash /] );
+    use YAML::PP::Schema::Tie::IxHash;
+    my $yp = YAML::PP->new( schema => [qw/ JSON Tie::IxHash /] );
 
     tie(my %ordered, 'Tie::IxHash');
     %ordered = (
@@ -61,8 +62,6 @@ YAML::PP::Schema::Tie::IxHash - (Deprecated) Schema for serializing ordered hash
 
 =head1 DESCRIPTION
 
-This is deprecated. See the new option C<preserve> in L<YAML::PP>.
-
 This schema allows you to dump ordered hashes which are tied to
 L<Tie::IxHash>.
 
@@ -142,15 +141,3 @@ Examples:
 =cut
 
 ### END EXAMPLE
-
-=head1 METHODS
-
-=over
-
-=item register
-
-Called by YAML::PP::Schema
-
-=back
-
-=cut
