@@ -2,14 +2,9 @@ use strict;
 use warnings;
 package YAML::PP::Schema::YAML1_1;
 
-our $VERSION = 'v0.38.1'; # VERSION
+use base 'YAML::PP::Schema';
 
-use YAML::PP::Schema::JSON qw/
-    represent_int represent_float represent_literal represent_bool
-    represent_undef
-/;
-
-use YAML::PP::Common qw/ YAML_PLAIN_SCALAR_STYLE /;
+use YAML::PP::Common qw/ YAML_PLAIN_SCALAR_STYLE YAML_QUOTED_SCALAR_STYLE /;
 
 #https://yaml.org/type/bool.html
 # y|Y|yes|Yes|YES|n|N|no|No|NO
@@ -34,7 +29,7 @@ use YAML::PP::Common qw/ YAML_PLAIN_SCALAR_STYLE /;
 # |null|Null|NULL # (English)
 # | # (Empty)
 
-my $RE_INT_1_1 = qr{^([+-]?(?:0|[1-9][0-9_]*))$};
+my $RE_INT_1_1 = qr{^([+-]?(?:[0-9_]+))$};
 #my $RE_FLOAT_1_1 = qr{^([+-]?([0-9][0-9_]*)?\.[0-9.]*([eE][+-][0-9]+)?)$};
 # https://yaml.org/type/float.html has a bug. The regex says \.[0-9.], but
 # probably means \.[0-9_]
@@ -45,24 +40,28 @@ my $RE_INT_OCTAL_1_1 = qr{^([+-]?)0([0-7_]+)$};
 my $RE_INT_HEX_1_1 = qr{^([+-]?)(0x[0-9a-fA-F_]+)$};
 my $RE_INT_BIN_1_1 = qr{^([-+]?)(0b[0-1_]+)$};
 
+
+sub new {
+    my ($class, %args) = @_;
+    my $self = bless {}, $class;
+    return $self;
+}
+
 sub _from_oct {
-    my ($constructor, $event, $matches) = @_;
-    my ($sign, $oct) = @$matches;
+    my ($sign, $oct) = @_;
     $oct =~ tr/_//d;
     my $result = oct $oct;
     $result = -$result if $sign eq '-';
     return $result;
 }
 sub _from_hex {
-    my ($constructor, $event, $matches) = @_;
-    my ($sign, $hex) = @$matches;
+    my ($sign, $hex) = @_;
     my $result = hex $hex;
     $result = -$result if $sign eq '-';
     return $result;
 }
 sub _sexa_to_float {
-    my ($constructor, $event, $matches) = @_;
-    my ($float) = @$matches;
+    my ($float) = @_;
     my $result = 0;
     my $i = 0;
     my $sign = 1;
@@ -75,15 +74,13 @@ sub _sexa_to_float {
     return $result * $sign;
 }
 sub _to_float {
-    my ($constructor, $event, $matches) = @_;
-    my ($float) = @$matches;
+    my ($float) = @_;
     $float =~ tr/_//d;
     $float = unpack F => pack F => $float;
     return $float;
 }
 sub _to_int {
-    my ($constructor, $event, $matches) = @_;
-    my ($int) = @$matches;
+    my ($int) = @_;
     $int =~ tr/_//d;
     0 + $int;
 }
@@ -146,26 +143,68 @@ sub register {
     ) for (qw/ .nan .NaN .NAN /);
     $schema->add_resolver(
         tag => 'tag:yaml.org,2002:str',
-        match => [ all => sub { $_[1]->{value} } ],
+        match => [ regex => qr{^(.*)$} => sub { $_[0] } ],
         implicit => 0,
     );
 
+    $schema->add_representer(
+        reftype => "*",
+        code => sub {
+            die "Dumping references not supported yet";
+        },
+    );
+
     my $int_flags = B::SVp_IOK;
     my $float_flags = B::SVp_NOK;
     $schema->add_representer(
         flags => $int_flags,
-        code => \&represent_int,
+        code => sub {
+            my ($rep, $node) = @_;
+            if (int($node->{value}) ne $node->{value}) {
+                return 0;
+            }
+            $node->{style} = YAML_PLAIN_SCALAR_STYLE;
+            $node->{data} = "$node->{value}";
+            return 1;
+        },
     );
+    my %special = ( (0+'nan').'' => '.nan', (0+'inf').'' => '.inf', (0-'inf').'' => '-.inf' );
     $schema->add_representer(
         flags => $float_flags,
-        code => \&represent_float,
+        code => sub {
+            my ($rep, $node) = @_;
+            if (exists $special{ $node->{value} }) {
+                $node->{style} = YAML_PLAIN_SCALAR_STYLE;
+                $node->{data} = $special{ $node->{value} };
+                return 1;
+            }
+            if (0.0 + $node->{value} ne $node->{value}) {
+                return 0;
+            }
+            if (int($node->{value}) eq $node->{value} and not $node->{value} =~ m/\./) {
+                $node->{value} .= '.0';
+            }
+            $node->{style} = YAML_PLAIN_SCALAR_STYLE;
+            $node->{data} = "$node->{value}";
+            return 1;
+        },
     );
     $schema->add_representer(
-        undefined => \&represent_undef,
+        undefined => sub {
+            my ($rep, $node) = @_;
+            $node->{style} = YAML_PLAIN_SCALAR_STYLE;
+            $node->{data} = 'null';
+            return 1;
+        },
     );
     $schema->add_representer(
         equals => $_,
-        code => \&represent_literal,
+        code => sub {
+            my ($rep, $node) = @_;
+            $node->{style} = YAML_QUOTED_SCALAR_STYLE;
+            $node->{data} = "$node->{value}";
+            return 1;
+        },
     ) for ("", qw/
         true TRUE True y Y yes Yes YES on On ON
         false FALSE False n N n no No NO off Off OFF
@@ -174,23 +213,26 @@ sub register {
     /);
     $schema->add_representer(
         regex => qr{$RE_INT_1_1|$RE_FLOAT_1_1|$RE_INT_OCTAL_1_1|$RE_INT_HEX_1_1|$RE_INT_BIN_1_1|$RE_SEXAGESIMAL_INT|$RE_SEXAGESIMAL},
-        code => \&represent_literal,
+        code => sub {
+            my ($rep, $node) = @_;
+            $node->{style} = YAML_QUOTED_SCALAR_STYLE;
+            $node->{data} = "$node->{value}";
+            return 1;
+        },
     );
 
     if ($schema->bool_class) {
-        for my $class (@{ $schema->bool_class }) {
-            if ($class eq 'perl') {
-                $schema->add_representer(
-                    bool => 1,
-                    code => \&represent_bool,
-                );
-                next;
-            }
-            $schema->add_representer(
-                class_equals => $class,
-                code => \&represent_bool,
-            );
-        }
+        $schema->add_representer(
+            class_equals => $schema->bool_class,
+            code => sub {
+                my ($rep, $node) = @_;
+                my $string = $node->{value} ? 'true' : 'false';
+                $node->{style} = YAML_PLAIN_SCALAR_STYLE;
+                @{ $node->{items} } = $string;
+                $node->{data} = $string;
+                return 1;
+            },
+        );
     }
 
     return;
@@ -212,6 +254,7 @@ YAML::PP::Schema::YAML1_1 - YAML 1.1 Schema for YAML::PP
 =head1 SYNOPSIS
 
     use YAML::PP;
+    use YAML::PP::Schema::YAML1_1;
 
     my $yp = YAML::PP->new( schema => ['YAML1_1'] );
     my $yaml = <<'EOM';
@@ -224,16 +267,6 @@ YAML::PP::Schema::YAML1_1 - YAML 1.1 Schema for YAML::PP
 
 This schema allows you to load the common YAML Types from YAML 1.1.
 
-=head1 METHODS
-
-=over
-
-=item register
-
-Called by YAML::PP::Schema
-
-=back
-
 =head1 SEE ALSO
 
 =over
